# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## [0.2.0](https://github.com/serge724/doc2data/tree/v0.2.0) - 2022-10-17

***Added***

- doc2data.experimental subpackage for feature extraction and model training
- How-to guides in Google Colab

## [0.1.0](https://github.com/serge724/doc2data/tree/v0.1.0) - 2022-08-30

***Added***

- Project configuration
- Project documentation
- doc2data.pdf module for working with PDF collections
- doc2data.utils module with utilities

## [0.0.1](https://github.com/serge724/doc2data/tree/v0.0.1) - 2022-05-10

***Added***

- Hatch project skeleton as initial commit
